DateTimeCond class

CreateDate

Constructors

DateTimeCond({required DateTime min, required DateTime max, bool ignore = false})
const
DateTimeCond.def()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignore → bool
final
max → DateTime
final
min → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? min, DateTime? max, bool? ignore}) → DateTimeCond
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

zero → DateTime
final