HeaderSetting class

Settings for gallery header

Constructors

HeaderSetting({double topMargin = 70.0, double headerMaxHeight = 56.0, double headerMinHeight = 25.0, Widget headerBackground = const ColoredBox(color: Colors.black), dynamic headerLeftWidget = Icons.close, Widget headerRightWidget = const SizedBox(), Widget albumBuilder(BuildContext, BaseState<AssetPathEntity>, Widget?)?, FlexFit albumFit = FlexFit.loose, double elevation = 0, Size barSize = const Size(40, 5), BorderRadius borderRadius = BorderRadius.zero})
const

Properties

albumBuilder → Widget Function(BuildContext, BaseState<AssetPathEntity>, Widget?)?
Background widget for panel header, IconData or Widget Default: Icons.close
final
albumFit → FlexFit
final
barSize → Size
Default: BorderRadius.zero
final
borderRadius → BorderRadius
BorderRadius of header Default: BorderRadius.zero
final
elevation → double
Default: 0 px
final
hashCode → int
The hash code for this object.
no setterinherited
headerBackground → Widget
Background widget for panel header, Default: Sizebox()
final
headerLeftWidget → dynamic
IconData or Widget Default: Icons.close
final
headerMaxHeight → double
Panel header maximum size
final
headerMinHeight → double
Panel header minimum size,
final
headerRightWidget → Widget
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topMargin → double
Margin for panel top. Which can be used to show status bar if you need to show panel above scaffold. Default: 70.0 px
final

Methods

copyWith({double? topMargin, double? headerMaxHeight, double? headerMinHeight, Widget? headerBackground, double? elevation, dynamic headerLeftWidget, Widget? headerRightWidget, BorderRadius? borderRadius, Widget albumBuilder(BuildContext, BaseState<AssetPathEntity>, Widget?)?}) → HeaderSetting
Helper function
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited