Sticker class

A Dart object which holds metadata for a given sticker.

Implementers

Constructors

Sticker({String name = '', Size size = const Size(200.0, 200.0), ValueSetter<Sticker>? onPressed, Map<String, Object> extra = const {}})
A Dart object which holds metadata for a given sticker.
const

Properties

extra → Map<String, Object>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the sticker.
final
onPressed → ValueSetter<Sticker>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
The size of the asset. Default Size(100.0, 100.0)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited